@@ -7,7 +7,7 @@ Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
+published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
@@ -22,11 +22,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef KCALC_CORE_H_
 #define KCALC_CORE_H_
 
-#include <QStack>
-#include "stats.h"
 #include "knumber.h"
+#include "stats.h"
+#include <QStack>
 
-class CalcEngine {
+class CalcEngine
+{
 public:
     // operations that can be stored in calculation stack
     enum Operation {
@@ -49,11 +50,13 @@ public:
         FUNC_PWR_ROOT
     };
 
+    enum Repeat { REPEAT_ALLOW, REPEAT_PREVENT };
+
     CalcEngine();
 
     KNumber lastOutput(bool &error) const;
 
-    void enterOperation(const KNumber &num, Operation func);
+    void enterOperation(const KNumber &num, Operation func, Repeat allow_repeat = REPEAT_ALLOW);
 
     void ArcCosDeg(const KNumber &input);
     void ArcCosRad(const KNumber &input);
@@ -77,7 +80,7 @@ public:
     void Exp(const KNumber &input);
     void Exp10(const KNumber &input);
     void Factorial(const KNumber &input);
-	void Gamma(const KNumber &input);
+    void Gamma(const KNumber &input);
     void InvertSign(const KNumber &input);
     void Ln(const KNumber &input);
     void Log10(const KNumber &input);
@@ -152,5 +155,4 @@ private:
     KNumber evalOperation(const KNumber &arg1, Operation operation, const KNumber &arg2);
 };
 
-
 #endif
